import yaml
from .const import SECRET_YAML as SECRET_YAML
from .objects import Input as Input, NodeListClass as NodeListClass, NodeStrClass as NodeStrClass
from collections import OrderedDict
from collections.abc import Iterator
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError
from pathlib import Path
from typing import Any, TextIO, TypeVar, Union, overload

JSON_TYPE = Union[list, dict, str]
DICT_T = TypeVar('DICT_T', bound=dict)
_LOGGER: Any

class Secrets:
    config_dir: Any
    _cache: Any
    def __init__(self, config_dir: Path) -> None: ...
    def get(self, requester_path: str, secret: str) -> str: ...
    def _load_secret_yaml(self, secret_dir: Path) -> dict[str, str]: ...

class SafeLineLoader(yaml.SafeLoader):
    secrets: Any
    def __init__(self, stream: Any, secrets: Union[Secrets, None] = ...) -> None: ...
    def compose_node(self, parent: yaml.nodes.Node, index: int) -> yaml.nodes.Node: ...

def load_yaml(fname: str, secrets: Union[Secrets, None] = ...) -> JSON_TYPE: ...
def parse_yaml(content: Union[str, TextIO], secrets: Union[Secrets, None] = ...) -> JSON_TYPE: ...
@overload
def _add_reference(obj: Union[list, NodeListClass], loader: SafeLineLoader, node: yaml.nodes.Node) -> NodeListClass: ...
@overload
def _add_reference(obj: Union[str, NodeStrClass], loader: SafeLineLoader, node: yaml.nodes.Node) -> NodeStrClass: ...
@overload
def _add_reference(obj: DICT_T, loader: SafeLineLoader, node: yaml.nodes.Node) -> DICT_T: ...
def _include_yaml(loader: SafeLineLoader, node: yaml.nodes.Node) -> JSON_TYPE: ...
def _is_file_valid(name: str) -> bool: ...
def _find_files(directory: str, pattern: str) -> Iterator[str]: ...
def _include_dir_named_yaml(loader: SafeLineLoader, node: yaml.nodes.Node) -> OrderedDict: ...
def _include_dir_merge_named_yaml(loader: SafeLineLoader, node: yaml.nodes.Node) -> OrderedDict: ...
def _include_dir_list_yaml(loader: SafeLineLoader, node: yaml.nodes.Node) -> list[JSON_TYPE]: ...
def _include_dir_merge_list_yaml(loader: SafeLineLoader, node: yaml.nodes.Node) -> JSON_TYPE: ...
def _ordered_dict(loader: SafeLineLoader, node: yaml.nodes.MappingNode) -> OrderedDict: ...
def _construct_seq(loader: SafeLineLoader, node: yaml.nodes.Node) -> JSON_TYPE: ...
def _env_var_yaml(loader: SafeLineLoader, node: yaml.nodes.Node) -> str: ...
def secret_yaml(loader: SafeLineLoader, node: yaml.nodes.Node) -> JSON_TYPE: ...



from . import DEVICE_TRIGGER_BASE_SCHEMA as DEVICE_TRIGGER_BASE_SCHEMA
from homeassistant.components.automation import AutomationActionType as AutomationActionType
from homeassistant.components.device_automation.const import CONF_IS_OFF as CONF_IS_OFF, CONF_IS_ON as CONF_IS_ON, CONF_TOGGLE as CONF_TOGGLE, CONF_TURNED_OFF as CONF_TURNED_OFF, CONF_TURNED_ON as CONF_TURNED_ON, CONF_TURN_OFF as CONF_TURN_OFF, CONF_TURN_ON as CONF_TURN_ON
from homeassistant.const import ATTR_ENTITY_ID as ATTR_ENTITY_ID, CONF_CONDITION as CONF_CONDITION, CONF_ENTITY_ID as CONF_ENTITY_ID, CONF_FOR as CONF_FOR, CONF_PLATFORM as CONF_PLATFORM, CONF_TYPE as CONF_TYPE
from homeassistant.core import CALLBACK_TYPE as CALLBACK_TYPE, Context as Context, HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers import condition as condition
from homeassistant.helpers.entity_registry import async_entries_for_device as async_entries_for_device
from homeassistant.helpers.typing import ConfigType as ConfigType, TemplateVarsType as TemplateVarsType
from typing import Any

ENTITY_ACTIONS: Any
ENTITY_CONDITIONS: Any
ENTITY_TRIGGERS: Any
DEVICE_ACTION_TYPES: Any
ACTION_SCHEMA: Any
CONDITION_SCHEMA: Any
TRIGGER_SCHEMA: Any

async def async_call_action_from_config(hass: HomeAssistant, config: ConfigType, variables: TemplateVarsType, context: Context, domain: str) -> None: ...
def async_condition_from_config(config: ConfigType) -> condition.ConditionCheckerType: ...
async def async_attach_trigger(hass: HomeAssistant, config: ConfigType, action: AutomationActionType, automation_info: dict) -> CALLBACK_TYPE: ...
async def _async_get_automations(hass: HomeAssistant, device_id: str, automation_templates: list[dict], domain: str) -> list[dict]: ...
async def async_get_actions(hass: HomeAssistant, device_id: str, domain: str) -> list[dict]: ...
async def async_get_conditions(hass: HomeAssistant, device_id: str, domain: str) -> list[dict[str, str]]: ...
async def async_get_triggers(hass: HomeAssistant, device_id: str, domain: str) -> list[dict]: ...
async def async_get_condition_capabilities(hass: HomeAssistant, config: dict) -> dict: ...
async def async_get_trigger_capabilities(hass: HomeAssistant, config: dict) -> dict: ...



from aiohttp import web
from homeassistant.components.http import HomeAssistantView as HomeAssistantView
from homeassistant.components.media_player.const import ATTR_MEDIA_CONTENT_ID as ATTR_MEDIA_CONTENT_ID, ATTR_MEDIA_CONTENT_TYPE as ATTR_MEDIA_CONTENT_TYPE, MEDIA_TYPE_MUSIC as MEDIA_TYPE_MUSIC, SERVICE_PLAY_MEDIA as SERVICE_PLAY_MEDIA
from homeassistant.const import ATTR_ENTITY_ID as ATTR_ENTITY_ID, CONF_DESCRIPTION as CONF_DESCRIPTION, CONF_NAME as CONF_NAME, CONF_PLATFORM as CONF_PLATFORM, HTTP_BAD_REQUEST as HTTP_BAD_REQUEST, HTTP_NOT_FOUND as HTTP_NOT_FOUND, PLATFORM_FORMAT as PLATFORM_FORMAT
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError
from homeassistant.helpers import config_per_platform as config_per_platform, discovery as discovery
from homeassistant.helpers.network import get_url as get_url
from homeassistant.helpers.service import async_set_service_schema as async_set_service_schema
from homeassistant.loader import async_get_integration as async_get_integration
from homeassistant.setup import async_prepare_setup_platform as async_prepare_setup_platform
from homeassistant.util.yaml import load_yaml as load_yaml
from typing import Any, Optional, Tuple

_LOGGER: Any
TtsAudioType = Tuple[Optional[str], Optional[bytes]]
ATTR_CACHE: str
ATTR_LANGUAGE: str
ATTR_MESSAGE: str
ATTR_OPTIONS: str
ATTR_PLATFORM: str
BASE_URL_KEY: str
CONF_BASE_URL: str
CONF_CACHE: str
CONF_CACHE_DIR: str
CONF_LANG: str
CONF_SERVICE_NAME: str
CONF_TIME_MEMORY: str
CONF_FIELDS: str
DEFAULT_CACHE: bool
DEFAULT_CACHE_DIR: str
DEFAULT_TIME_MEMORY: int
DOMAIN: str
MEM_CACHE_FILENAME: str
MEM_CACHE_VOICE: str
SERVICE_CLEAR_CACHE: str
SERVICE_SAY: str
_RE_VOICE_FILE: Any
KEY_PATTERN: str

def _deprecated_platform(value): ...

PLATFORM_SCHEMA: Any
PLATFORM_SCHEMA_BASE: Any
SCHEMA_SERVICE_SAY: Any
SCHEMA_SERVICE_CLEAR_CACHE: Any

async def async_setup(hass, config): ...
def _hash_options(options: dict) -> str: ...

class SpeechManager:
    hass: Any
    providers: Any
    use_cache: Any
    cache_dir: Any
    time_memory: Any
    base_url: Any
    file_cache: Any
    mem_cache: Any
    def __init__(self, hass) -> None: ...
    async def async_init_cache(self, use_cache, cache_dir, time_memory, base_url) -> None: ...
    async def async_clear_cache(self) -> None: ...
    def async_register_engine(self, engine, provider, config) -> None: ...
    async def async_get_url_path(self, engine, message, cache: Any | None = ..., language: Any | None = ..., options: Any | None = ...): ...
    async def async_get_tts_audio(self, engine, key, message, cache, language, options): ...
    async def async_save_tts_audio(self, key, filename, data) -> None: ...
    async def async_file_to_mem(self, key): ...
    def _async_store_to_memcache(self, key, filename, data) -> None: ...
    async def async_read_tts(self, filename): ...
    @staticmethod
    def write_tags(filename, data, provider, message, language, options): ...

class Provider:
    hass: Union[HomeAssistant, None]
    name: Union[str, None]
    @property
    def default_language(self) -> None: ...
    @property
    def supported_languages(self) -> None: ...
    @property
    def supported_options(self) -> None: ...
    @property
    def default_options(self) -> None: ...
    def get_tts_audio(self, message, language, options: Any | None = ...) -> None: ...
    async def async_get_tts_audio(self, message, language, options: Any | None = ...): ...

def _init_tts_cache_dir(hass, cache_dir): ...
def _get_cache_files(cache_dir): ...

class TextToSpeechUrlView(HomeAssistantView):
    requires_auth: bool
    url: str
    name: str
    tts: Any
    def __init__(self, tts) -> None: ...
    async def post(self, request: web.Request) -> web.Response: ...

class TextToSpeechView(HomeAssistantView):
    requires_auth: bool
    url: str
    name: str
    tts: Any
    def __init__(self, tts) -> None: ...
    async def get(self, request: web.Request, filename: str) -> web.Response: ...

def get_base_url(hass): ...



from . import local_auth as local_auth
from .const import DATA_NEST as DATA_NEST, DATA_NEST_CONFIG as DATA_NEST_CONFIG, DOMAIN as DOMAIN, SIGNAL_NEST_UPDATE as SIGNAL_NEST_UPDATE
from homeassistant import config_entries as config_entries
from homeassistant.const import CONF_CLIENT_ID as CONF_CLIENT_ID, CONF_CLIENT_SECRET as CONF_CLIENT_SECRET, CONF_FILENAME as CONF_FILENAME, CONF_STRUCTURE as CONF_STRUCTURE, EVENT_HOMEASSISTANT_START as EVENT_HOMEASSISTANT_START, EVENT_HOMEASSISTANT_STOP as EVENT_HOMEASSISTANT_STOP
from homeassistant.core import callback as callback
from homeassistant.helpers.dispatcher import async_dispatcher_connect as async_dispatcher_connect, dispatcher_send as dispatcher_send
from homeassistant.helpers.entity import Entity as Entity
from typing import Any

_CONFIGURING: Any
_LOGGER: Any
PLATFORMS: Any
SERVICE_CANCEL_ETA: str
SERVICE_SET_ETA: str
NEST_CONFIG_FILE: str
ATTR_ETA: str
ATTR_ETA_WINDOW: str
ATTR_STRUCTURE: str
ATTR_TRIP_ID: str
AWAY_MODE_AWAY: str
AWAY_MODE_HOME: str
ATTR_AWAY_MODE: str
SERVICE_SET_AWAY_MODE: str
SET_AWAY_MODE_SCHEMA: Any
SET_ETA_SCHEMA: Any
CANCEL_ETA_SCHEMA: Any

def nest_update_event_broker(hass, nest) -> None: ...
async def async_setup_legacy(hass, config) -> bool: ...
async def async_setup_legacy_entry(hass, entry) -> bool: ...

class NestLegacyDevice:
    hass: Any
    nest: Any
    local_structure: Any
    def __init__(self, hass, conf, nest) -> None: ...
    def initialize(self): ...
    def structures(self) -> None: ...
    def thermostats(self): ...
    def smoke_co_alarms(self): ...
    def cameras(self): ...
    def _devices(self, device_type) -> None: ...

class NestSensorDevice(Entity):
    structure: Any
    variable: Any
    device: Any
    _name: Any
    _state: Any
    _unit: Any
    def __init__(self, structure, device, variable) -> None: ...
    @property
    def name(self): ...
    @property
    def should_poll(self): ...
    @property
    def unique_id(self): ...
    @property
    def device_info(self): ...
    def update(self) -> None: ...
    async def async_added_to_hass(self) -> None: ...



from aiohttp.web import Application as Application, Request as Request, StreamResponse as StreamResponse
from collections.abc import Callable as Callable
from homeassistant.core import callback as callback
from typing import Any

_LOGGER: Any

def async_setup_forwarded(app: Application, use_x_forwarded_for: Union[bool, None], trusted_proxies: list[str]) -> None: ...



from .const import CONF_DIM_MODE as CONF_DIM_MODE, CONF_SK_NUM_TRIES as CONF_SK_NUM_TRIES, CONNECTION as CONNECTION, DOMAIN as DOMAIN, PLATFORMS as PLATFORMS
from .helpers import DeviceConnectionType as DeviceConnectionType, InputType as InputType, generate_unique_id as generate_unique_id, import_lcn_config as import_lcn_config
from .schemas import CONFIG_SCHEMA as CONFIG_SCHEMA
from .services import SERVICES as SERVICES
from homeassistant import config_entries as config_entries
from homeassistant.const import CONF_IP_ADDRESS as CONF_IP_ADDRESS, CONF_NAME as CONF_NAME, CONF_PASSWORD as CONF_PASSWORD, CONF_PORT as CONF_PORT, CONF_RESOURCE as CONF_RESOURCE, CONF_USERNAME as CONF_USERNAME
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity import Entity as Entity
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any

_LOGGER: Any

async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool: ...
async def async_setup_entry(hass: HomeAssistant, config_entry: config_entries.ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, config_entry: config_entries.ConfigEntry) -> bool: ...

class LcnEntity(Entity):
    config: Any
    entry_id: Any
    device_connection: Any
    _unregister_for_inputs: Any
    _name: Any
    def __init__(self, config: ConfigType, entry_id: str, device_connection: DeviceConnectionType) -> None: ...
    @property
    def unique_id(self) -> str: ...
    @property
    def should_poll(self) -> bool: ...
    async def async_added_to_hass(self) -> None: ...
    async def async_will_remove_from_hass(self) -> None: ...
    @property
    def name(self) -> str: ...
    def input_received(self, input_obj: InputType) -> None: ...



import threading
from typing import Any

THREADING_SHUTDOWN_TIMEOUT: int
_LOGGER: Any

def deadlock_safe_shutdown() -> None: ...
def async_raise(tid: int, exctype: Any) -> None: ...

class ThreadWithException(threading.Thread):
    def raise_exc(self, exctype: Any) -> None: ...



import voluptuous as vol
from .const import CONF_ZONE_RUN_TIME as CONF_ZONE_RUN_TIME, DEFAULT_PORT as DEFAULT_PORT, DEFAULT_ZONE_RUN as DEFAULT_ZONE_RUN, DOMAIN as DOMAIN
from homeassistant import config_entries as config_entries
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import CONF_IP_ADDRESS as CONF_IP_ADDRESS, CONF_PASSWORD as CONF_PASSWORD, CONF_PORT as CONF_PORT, CONF_SSL as CONF_SSL
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.data_entry_flow import FlowResult as FlowResult
from homeassistant.helpers import aiohttp_client as aiohttp_client
from homeassistant.helpers.typing import DiscoveryInfoType as DiscoveryInfoType
from regenmaschine import Client
from regenmaschine.controller import Controller as Controller
from typing import Any

def get_client_controller(client: Client) -> Controller: ...
async def async_get_controller(hass: HomeAssistant, ip_address: str, password: str, port: int, ssl: bool) -> Union[Controller, None]: ...

class RainMachineFlowHandler(config_entries.ConfigFlow):
    VERSION: int
    discovered_ip_address: Union[str, None]
    @staticmethod
    def async_get_options_flow(config_entry: ConfigEntry) -> RainMachineOptionsFlowHandler: ...
    async def async_step_homekit(self, discovery_info: DiscoveryInfoType) -> FlowResult: ...
    async def async_step_zeroconf(self, discovery_info: DiscoveryInfoType) -> FlowResult: ...
    def _async_generate_schema(self) -> vol.Schema: ...
    async def async_step_user(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...

class RainMachineOptionsFlowHandler(config_entries.OptionsFlow):
    config_entry: Any
    def __init__(self, config_entry: ConfigEntry) -> None: ...
    async def async_step_init(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...



import datetime as dt
from homeassistant.const import MATCH_ALL as MATCH_ALL
from typing import Any

DATE_STR_FORMAT: str
UTC: Any
DEFAULT_TIME_ZONE: dt.tzinfo
DATETIME_RE: Any

def set_default_time_zone(time_zone: dt.tzinfo) -> None: ...
def get_time_zone(time_zone_str: str) -> Union[dt.tzinfo, None]: ...
def utcnow() -> dt.datetime: ...
def now(time_zone: Union[dt.tzinfo, None] = ...) -> dt.datetime: ...
def as_utc(dattim: dt.datetime) -> dt.datetime: ...
def as_timestamp(dt_value: Union[dt.datetime, str]) -> float: ...
def as_local(dattim: dt.datetime) -> dt.datetime: ...
def utc_from_timestamp(timestamp: float) -> dt.datetime: ...
def start_of_local_day(dt_or_d: Union[dt.date, dt.datetime, None] = ...) -> dt.datetime: ...
def parse_datetime(dt_str: str) -> Union[dt.datetime, None]: ...
def parse_date(dt_str: str) -> Union[dt.date, None]: ...
def parse_time(time_str: str) -> Union[dt.time, None]: ...
def get_age(date: dt.datetime) -> str: ...
def parse_time_expression(parameter: Any, min_value: int, max_value: int) -> list[int]: ...
def _dst_offset_diff(dattim: dt.datetime) -> dt.timedelta: ...
def find_next_time_expression_time(now: dt.datetime, seconds: list[int], minutes: list[int], hours: list[int]) -> dt.datetime: ...
def _datetime_exists(dattim: dt.datetime) -> bool: ...
def _datetime_ambiguous(dattim: dt.datetime) -> bool: ...



from .const import CONF_KNX_EXPOSE as CONF_KNX_EXPOSE, CONF_KNX_INDIVIDUAL_ADDRESS as CONF_KNX_INDIVIDUAL_ADDRESS, CONF_KNX_ROUTING as CONF_KNX_ROUTING, CONF_KNX_TUNNELING as CONF_KNX_TUNNELING, DOMAIN as DOMAIN, KNX_ADDRESS as KNX_ADDRESS, SupportedPlatforms as SupportedPlatforms
from .expose import KNXExposeSensor as KNXExposeSensor, KNXExposeTime as KNXExposeTime, create_knx_exposure as create_knx_exposure
from .schema import BinarySensorSchema as BinarySensorSchema, ClimateSchema as ClimateSchema, ConnectionSchema as ConnectionSchema, CoverSchema as CoverSchema, ExposeSchema as ExposeSchema, FanSchema as FanSchema, LightSchema as LightSchema, NotifySchema as NotifySchema, NumberSchema as NumberSchema, SceneSchema as SceneSchema, SelectSchema as SelectSchema, SensorSchema as SensorSchema, SwitchSchema as SwitchSchema, WeatherSchema as WeatherSchema, ga_validator as ga_validator, sensor_type_validator as sensor_type_validator
from homeassistant.const import CONF_HOST as CONF_HOST, CONF_PORT as CONF_PORT, EVENT_HOMEASSISTANT_STOP as EVENT_HOMEASSISTANT_STOP, SERVICE_RELOAD as SERVICE_RELOAD
from homeassistant.core import Event as Event, HomeAssistant as HomeAssistant, ServiceCall as ServiceCall
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError
from homeassistant.helpers import discovery as discovery
from homeassistant.helpers.entity_platform import async_get_platforms as async_get_platforms
from homeassistant.helpers.reload import async_integration_yaml_config as async_integration_yaml_config
from homeassistant.helpers.service import async_register_admin_service as async_register_admin_service
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any, Final
from xknx.core.telegram_queue import TelegramQueue as TelegramQueue
from xknx.io import ConnectionConfig
from xknx.telegram import Telegram

_LOGGER: Any
CONF_KNX_FIRE_EVENT: Final[str]
CONF_KNX_EVENT_FILTER: Final[str]
SERVICE_KNX_SEND: Final[str]
SERVICE_KNX_ATTR_PAYLOAD: Final[str]
SERVICE_KNX_ATTR_TYPE: Final[str]
SERVICE_KNX_ATTR_REMOVE: Final[str]
SERVICE_KNX_EVENT_REGISTER: Final[str]
SERVICE_KNX_EXPOSURE_REGISTER: Final[str]
SERVICE_KNX_READ: Final[str]
CONFIG_SCHEMA: Any
SERVICE_KNX_SEND_SCHEMA: Any
SERVICE_KNX_READ_SCHEMA: Any
SERVICE_KNX_EVENT_REGISTER_SCHEMA: Any
SERVICE_KNX_EXPOSURE_REGISTER_SCHEMA: Any

async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool: ...

class KNXModule:
    hass: Any
    config: Any
    connected: bool
    exposures: Any
    service_exposures: Any
    _knx_event_callback: Any
    def __init__(self, hass: HomeAssistant, config: ConfigType) -> None: ...
    xknx: Any
    def init_xknx(self) -> None: ...
    async def start(self) -> None: ...
    async def stop(self, event: Event) -> None: ...
    def connection_config(self) -> ConnectionConfig: ...
    def connection_config_routing(self) -> ConnectionConfig: ...
    def connection_config_tunneling(self) -> ConnectionConfig: ...
    async def telegram_received_cb(self, telegram: Telegram) -> None: ...
    def register_callback(self) -> TelegramQueue.Callback: ...
    async def service_event_register_modify(self, call: ServiceCall) -> None: ...
    async def service_exposure_register_modify(self, call: ServiceCall) -> None: ...
    async def service_send_to_knx_bus(self, call: ServiceCall) -> None: ...
    async def service_read_to_knx_bus(self, call: ServiceCall) -> None: ...



import logging
from collections.abc import Mapping, MutableMapping
from typing import Any

class KeywordMessage:
    _fmt: Any
    _args: Any
    _kwargs: Any
    def __init__(self, fmt: Any, args: Any, kwargs: Mapping[str, Any]) -> None: ...
    def __str__(self) -> str: ...

class KeywordStyleAdapter(logging.LoggerAdapter):
    def __init__(self, logger: logging.Logger, extra: Union[Mapping[str, Any], None] = ...) -> None: ...
    def log(self, level: int, msg: Any, *args: Any, **kwargs: Any) -> None: ...
    def process(self, msg: Any, kwargs: MutableMapping[str, Any]) -> tuple[Any, MutableMapping[str, Any]]: ...



from . import DOMAIN as DOMAIN
from collections.abc import Iterable
from homeassistant.const import ATTR_ENTITY_ID as ATTR_ENTITY_ID, SERVICE_ALARM_ARM_AWAY as SERVICE_ALARM_ARM_AWAY, SERVICE_ALARM_ARM_CUSTOM_BYPASS as SERVICE_ALARM_ARM_CUSTOM_BYPASS, SERVICE_ALARM_ARM_HOME as SERVICE_ALARM_ARM_HOME, SERVICE_ALARM_ARM_NIGHT as SERVICE_ALARM_ARM_NIGHT, SERVICE_ALARM_ARM_VACATION as SERVICE_ALARM_ARM_VACATION, SERVICE_ALARM_DISARM as SERVICE_ALARM_DISARM, SERVICE_ALARM_TRIGGER as SERVICE_ALARM_TRIGGER, STATE_ALARM_ARMED_AWAY as STATE_ALARM_ARMED_AWAY, STATE_ALARM_ARMED_CUSTOM_BYPASS as STATE_ALARM_ARMED_CUSTOM_BYPASS, STATE_ALARM_ARMED_HOME as STATE_ALARM_ARMED_HOME, STATE_ALARM_ARMED_NIGHT as STATE_ALARM_ARMED_NIGHT, STATE_ALARM_ARMED_VACATION as STATE_ALARM_ARMED_VACATION, STATE_ALARM_DISARMED as STATE_ALARM_DISARMED, STATE_ALARM_TRIGGERED as STATE_ALARM_TRIGGERED
from homeassistant.core import Context as Context, HomeAssistant as HomeAssistant, State as State
from typing import Any, Final

_LOGGER: Final[Any]
VALID_STATES: Final[set[str]]

async def _async_reproduce_state(hass: HomeAssistant, state: State, *, context: Union[Context, None] = ..., reproduce_options: Union[dict[str, Any], None] = ...) -> None: ...
async def async_reproduce_states(hass: HomeAssistant, states: Iterable[State], *, context: Union[Context, None] = ..., reproduce_options: Union[dict[str, Any], None] = ...) -> None: ...



from . import SimpliSafe as SimpliSafe, SimpliSafeBaseSensor as SimpliSafeBaseSensor
from .const import DATA_CLIENT as DATA_CLIENT, DOMAIN as DOMAIN, LOGGER as LOGGER
from homeassistant.components.binary_sensor import BinarySensorEntity as BinarySensorEntity, DEVICE_CLASS_BATTERY as DEVICE_CLASS_BATTERY, DEVICE_CLASS_DOOR as DEVICE_CLASS_DOOR, DEVICE_CLASS_GAS as DEVICE_CLASS_GAS, DEVICE_CLASS_MOISTURE as DEVICE_CLASS_MOISTURE, DEVICE_CLASS_MOTION as DEVICE_CLASS_MOTION, DEVICE_CLASS_SAFETY as DEVICE_CLASS_SAFETY, DEVICE_CLASS_SMOKE as DEVICE_CLASS_SMOKE
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from simplipy.entity import Entity as SimplipyEntity
from simplipy.system.v2 import SystemV2 as SystemV2
from simplipy.system.v3 import SystemV3 as SystemV3
from typing import Any

SUPPORTED_BATTERY_SENSOR_TYPES: Any
TRIGGERED_SENSOR_TYPES: Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class TriggeredBinarySensor(SimpliSafeBaseSensor, BinarySensorEntity):
    _attr_device_class: Any
    def __init__(self, simplisafe: SimpliSafe, system: Union[SystemV2, SystemV3], sensor: SimplipyEntity, device_class: str) -> None: ...
    _attr_is_on: Any
    def async_update_from_rest_api(self) -> None: ...

class BatteryBinarySensor(SimpliSafeBaseSensor, BinarySensorEntity):
    _attr_device_class: Any
    _attr_unique_id: Any
    def __init__(self, simplisafe: SimpliSafe, system: Union[SystemV2, SystemV3], sensor: SimplipyEntity) -> None: ...
    _attr_is_on: Any
    def async_update_from_rest_api(self) -> None: ...



from .const import CONF_TYPE_OWSERVER as CONF_TYPE_OWSERVER, DOMAIN as DOMAIN, SWITCH_TYPE_LATCH as SWITCH_TYPE_LATCH, SWITCH_TYPE_PIO as SWITCH_TYPE_PIO
from .model import DeviceComponentDescription as DeviceComponentDescription
from .onewire_entities import OneWireBaseEntity as OneWireBaseEntity, OneWireProxyEntity as OneWireProxyEntity
from .onewirehub import OneWireHub as OneWireHub
from homeassistant.components.switch import SwitchEntity as SwitchEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import CONF_TYPE as CONF_TYPE
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity import DeviceInfo as DeviceInfo
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any

DEVICE_SWITCHES: dict[str, list[DeviceComponentDescription]]
LOGGER: Any

async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...
def get_entities(onewirehub: OneWireHub) -> list[OneWireBaseEntity]: ...

class OneWireProxySwitch(OneWireProxyEntity, SwitchEntity):
    @property
    def is_on(self) -> bool: ...
    def turn_on(self, **kwargs: Any) -> None: ...
    def turn_off(self, **kwargs: Any) -> None: ...



import datetime
from . import ATTR_LAST_RESET as ATTR_LAST_RESET, DOMAIN as DOMAIN
from homeassistant.components.recorder import history as history, statistics as statistics
from homeassistant.components.sensor import ATTR_STATE_CLASS as ATTR_STATE_CLASS, DEVICE_CLASS_BATTERY as DEVICE_CLASS_BATTERY, DEVICE_CLASS_ENERGY as DEVICE_CLASS_ENERGY, DEVICE_CLASS_HUMIDITY as DEVICE_CLASS_HUMIDITY, DEVICE_CLASS_MONETARY as DEVICE_CLASS_MONETARY, DEVICE_CLASS_PRESSURE as DEVICE_CLASS_PRESSURE, DEVICE_CLASS_TEMPERATURE as DEVICE_CLASS_TEMPERATURE, STATE_CLASS_MEASUREMENT as STATE_CLASS_MEASUREMENT
from homeassistant.const import ATTR_DEVICE_CLASS as ATTR_DEVICE_CLASS, ATTR_UNIT_OF_MEASUREMENT as ATTR_UNIT_OF_MEASUREMENT, DEVICE_CLASS_POWER as DEVICE_CLASS_POWER, ENERGY_KILO_WATT_HOUR as ENERGY_KILO_WATT_HOUR, ENERGY_WATT_HOUR as ENERGY_WATT_HOUR, PERCENTAGE as PERCENTAGE, POWER_KILO_WATT as POWER_KILO_WATT, POWER_WATT as POWER_WATT, PRESSURE_BAR as PRESSURE_BAR, PRESSURE_HPA as PRESSURE_HPA, PRESSURE_INHG as PRESSURE_INHG, PRESSURE_MBAR as PRESSURE_MBAR, PRESSURE_PA as PRESSURE_PA, PRESSURE_PSI as PRESSURE_PSI, TEMP_CELSIUS as TEMP_CELSIUS, TEMP_FAHRENHEIT as TEMP_FAHRENHEIT, TEMP_KELVIN as TEMP_KELVIN
from homeassistant.core import HomeAssistant as HomeAssistant, State as State
from typing import Any, Callable

_LOGGER: Any
DEVICE_CLASS_OR_UNIT_STATISTICS: Any
DEVICE_CLASS_UNITS: Any
UNIT_CONVERSIONS: dict[str, dict[str, Callable]]
WARN_UNSUPPORTED_UNIT: Any

def _get_entities(hass: HomeAssistant) -> list[tuple[str, str]]: ...
def _is_number(s: str) -> bool: ...
def _time_weighted_average(fstates: list[tuple[float, State]], start: datetime.datetime, end: datetime.datetime) -> float: ...
def _normalize_states(entity_history: list[State], key: str, entity_id: str) -> tuple[Union[str, None], list[tuple[float, State]]]: ...
def compile_statistics(hass: HomeAssistant, start: datetime.datetime, end: datetime.datetime) -> dict: ...
def list_statistic_ids(hass: HomeAssistant, statistic_type: Union[str, None] = ...) -> dict: ...



import voluptuous as vol
from . import async_get_geography_id as async_get_geography_id
from .const import CONF_CITY as CONF_CITY, CONF_COUNTRY as CONF_COUNTRY, CONF_INTEGRATION_TYPE as CONF_INTEGRATION_TYPE, DOMAIN as DOMAIN, INTEGRATION_TYPE_GEOGRAPHY_COORDS as INTEGRATION_TYPE_GEOGRAPHY_COORDS, INTEGRATION_TYPE_GEOGRAPHY_NAME as INTEGRATION_TYPE_GEOGRAPHY_NAME, INTEGRATION_TYPE_NODE_PRO as INTEGRATION_TYPE_NODE_PRO, LOGGER as LOGGER
from homeassistant import config_entries as config_entries
from homeassistant.config_entries import ConfigEntry as ConfigEntry, OptionsFlow as OptionsFlow
from homeassistant.const import CONF_API_KEY as CONF_API_KEY, CONF_IP_ADDRESS as CONF_IP_ADDRESS, CONF_LATITUDE as CONF_LATITUDE, CONF_LONGITUDE as CONF_LONGITUDE, CONF_PASSWORD as CONF_PASSWORD, CONF_SHOW_ON_MAP as CONF_SHOW_ON_MAP, CONF_STATE as CONF_STATE
from homeassistant.core import callback as callback
from homeassistant.data_entry_flow import FlowResult as FlowResult
from homeassistant.helpers import aiohttp_client as aiohttp_client
from typing import Any

API_KEY_DATA_SCHEMA: Any
GEOGRAPHY_NAME_SCHEMA: Any
NODE_PRO_SCHEMA: Any
PICK_INTEGRATION_TYPE_SCHEMA: Any

class AirVisualFlowHandler(config_entries.ConfigFlow):
    VERSION: int
    _entry_data_for_reauth: Any
    _geo_id: Any
    def __init__(self) -> None: ...
    @property
    def geography_coords_schema(self) -> vol.Schema: ...
    async def _async_finish_geography(self, user_input: dict[str, str], integration_type: str) -> FlowResult: ...
    async def _async_init_geography(self, user_input: dict[str, str], integration_type: str) -> FlowResult: ...
    async def _async_set_unique_id(self, unique_id: str) -> None: ...
    @staticmethod
    def async_get_options_flow(config_entry: ConfigEntry) -> OptionsFlow: ...
    async def async_step_geography_by_coords(self, user_input: Union[dict[str, str], None] = ...) -> FlowResult: ...
    async def async_step_geography_by_name(self, user_input: Union[dict[str, str], None] = ...) -> FlowResult: ...
    async def async_step_node_pro(self, user_input: Union[dict[str, str], None] = ...) -> FlowResult: ...
    async def async_step_reauth(self, data: dict[str, str]) -> FlowResult: ...
    async def async_step_reauth_confirm(self, user_input: Union[dict[str, str], None] = ...) -> FlowResult: ...
    async def async_step_user(self, user_input: Union[dict[str, str], None] = ...) -> FlowResult: ...

class AirVisualOptionsFlowHandler(config_entries.OptionsFlow):
    config_entry: Any
    def __init__(self, config_entry: ConfigEntry) -> None: ...
    async def async_step_init(self, user_input: Union[dict[str, str], None] = ...) -> FlowResult: ...



from . import util as util
from .const import ATTR_ADAPTERS as ATTR_ADAPTERS, ATTR_CONFIGURED_ADAPTERS as ATTR_CONFIGURED_ADAPTERS, DOMAIN as DOMAIN, NETWORK_CONFIG_SCHEMA as NETWORK_CONFIG_SCHEMA
from .models import Adapter as Adapter
from .network import Network as Network
from homeassistant.components import websocket_api as websocket_api
from homeassistant.components.websocket_api.connection import ActiveConnection as ActiveConnection
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.typing import ConfigType as ConfigType
from homeassistant.loader import bind_hass as bind_hass
from typing import Any

ZEROCONF_DOMAIN: str
_LOGGER: Any

async def async_get_adapters(hass: HomeAssistant) -> list[Adapter]: ...
async def async_get_source_ip(hass: HomeAssistant, target_ip: str) -> str: ...
async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool: ...
async def websocket_network_adapters(hass: HomeAssistant, connection: ActiveConnection, msg: dict) -> None: ...
async def websocket_network_adapters_configure(hass: HomeAssistant, connection: ActiveConnection, msg: dict) -> None: ...



from homeassistant.components.trace import ActionTrace as ActionTrace, async_store_trace as async_store_trace
from homeassistant.components.trace.const import CONF_STORED_TRACES as CONF_STORED_TRACES
from homeassistant.core import Context as Context
from typing import Any

class AutomationTrace(ActionTrace):
    _trigger_description: Any
    def __init__(self, item_id: str, config: dict[str, Any], blueprint_inputs: dict[str, Any], context: Context) -> None: ...
    def set_trigger_description(self, trigger: str) -> None: ...
    def as_short_dict(self) -> dict[str, Any]: ...

def trace_automation(hass, automation_id, config, blueprint_inputs, context, trace_config) -> None: ...



from . import RainMachineEntity as RainMachineEntity, async_update_programs_and_zones as async_update_programs_and_zones
from .const import CONF_ZONE_RUN_TIME as CONF_ZONE_RUN_TIME, DATA_CONTROLLER as DATA_CONTROLLER, DATA_COORDINATOR as DATA_COORDINATOR, DATA_PROGRAMS as DATA_PROGRAMS, DATA_ZONES as DATA_ZONES, DEFAULT_ZONE_RUN as DEFAULT_ZONE_RUN, DOMAIN as DOMAIN, LOGGER as LOGGER
from collections.abc import Coroutine
from homeassistant.components.switch import SwitchEntity as SwitchEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import ATTR_ID as ATTR_ID
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers import entity_platform as entity_platform
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.update_coordinator import DataUpdateCoordinator as DataUpdateCoordinator
from regenmaschine.controller import Controller as Controller
from typing import Any

ATTR_AREA: str
ATTR_CS_ON: str
ATTR_CURRENT_CYCLE: str
ATTR_CYCLES: str
ATTR_DELAY: str
ATTR_DELAY_ON: str
ATTR_FIELD_CAPACITY: str
ATTR_NEXT_RUN: str
ATTR_NO_CYCLES: str
ATTR_PRECIP_RATE: str
ATTR_RESTRICTIONS: str
ATTR_SLOPE: str
ATTR_SOAK: str
ATTR_SOIL_TYPE: str
ATTR_SPRINKLER_TYPE: str
ATTR_STATUS: str
ATTR_SUN_EXPOSURE: str
ATTR_TIME_REMAINING: str
ATTR_VEGETATION_TYPE: str
ATTR_ZONES: str
CONF_PROGRAM_ID: str
CONF_SECONDS: str
CONF_ZONE_ID: str
DEFAULT_ICON: str
DAYS: Any
RUN_STATUS_MAP: Any
SOIL_TYPE_MAP: Any
SLOPE_TYPE_MAP: Any
SPRINKLER_TYPE_MAP: Any
SUN_EXPOSURE_MAP: Any
VEGETATION_MAP: Any
SWITCH_TYPE_PROGRAM: str
SWITCH_TYPE_ZONE: str

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class RainMachineSwitch(RainMachineEntity, SwitchEntity):
    _attr_icon: Any
    _attr_is_on: bool
    _attr_name: Any
    _data: Any
    _entry: Any
    _is_active: bool
    _uid: Any
    def __init__(self, coordinator: DataUpdateCoordinator, controller: Controller, uid: int, name: str, entry: ConfigEntry) -> None: ...
    @property
    def available(self) -> bool: ...
    @property
    def unique_id(self) -> str: ...
    async def _async_run_switch_coroutine(self, api_coro: Coroutine) -> None: ...
    async def async_disable_program(self, program_id: int) -> None: ...
    async def async_disable_zone(self, zone_id: int) -> None: ...
    async def async_enable_program(self, program_id: int) -> None: ...
    async def async_enable_zone(self, zone_id: int) -> None: ...
    async def async_pause_watering(self, seconds: int) -> None: ...
    async def async_start_program(self, program_id: int) -> None: ...
    async def async_start_zone(self, zone_id: int, zone_run_time: int) -> None: ...
    async def async_stop_all(self) -> None: ...
    async def async_stop_program(self, program_id: int) -> None: ...
    async def async_stop_zone(self, zone_id: int) -> None: ...
    async def async_unpause_watering(self) -> None: ...
    def update_from_latest_data(self) -> None: ...

class RainMachineProgram(RainMachineSwitch):
    @property
    def zones(self) -> list: ...
    async def async_turn_off(self, **kwargs: dict[str, Any]) -> None: ...
    async def async_turn_on(self, **kwargs: dict[str, Any]) -> None: ...
    _attr_is_on: Any
    def update_from_latest_data(self) -> None: ...

class RainMachineZone(RainMachineSwitch):
    async def async_turn_off(self, **kwargs: dict[str, Any]) -> None: ...
    async def async_turn_on(self, **kwargs: dict[str, Any]) -> None: ...
    _attr_is_on: Any
    def update_from_latest_data(self) -> None: ...



import httpx
from homeassistant.const import EVENT_HOMEASSISTANT_CLOSE as EVENT_HOMEASSISTANT_CLOSE, __version__ as __version__
from homeassistant.core import Event as Event, HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.frame import warn_use as warn_use
from homeassistant.loader import bind_hass as bind_hass
from typing import Any, Callable

DATA_ASYNC_CLIENT: str
DATA_ASYNC_CLIENT_NOVERIFY: str
SERVER_SOFTWARE: Any
USER_AGENT: str

def get_async_client(hass: HomeAssistant, verify_ssl: bool = ...) -> httpx.AsyncClient: ...

class HassHttpXAsyncClient(httpx.AsyncClient):
    async def __aenter__(self) -> HassHttpXAsyncClient: ...
    async def __aexit__(self, *args: Any) -> None: ...

def create_async_httpx_client(hass: HomeAssistant, verify_ssl: bool = ..., auto_cleanup: bool = ..., **kwargs: Any) -> httpx.AsyncClient: ...
def _async_register_async_client_shutdown(hass: HomeAssistant, client: httpx.AsyncClient, original_aclose: Callable[..., Any]) -> None: ...



from .const import CONF_TYPE_OWSERVER as CONF_TYPE_OWSERVER, DOMAIN as DOMAIN, SENSOR_TYPE_SENSED as SENSOR_TYPE_SENSED
from .model import DeviceComponentDescription as DeviceComponentDescription
from .onewire_entities import OneWireBaseEntity as OneWireBaseEntity, OneWireProxyEntity as OneWireProxyEntity
from .onewirehub import OneWireHub as OneWireHub
from homeassistant.components.binary_sensor import BinarySensorEntity as BinarySensorEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import CONF_TYPE as CONF_TYPE
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity import DeviceInfo as DeviceInfo
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback

DEVICE_BINARY_SENSORS: dict[str, list[DeviceComponentDescription]]

async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...
def get_entities(onewirehub: OneWireHub) -> list[OneWireBaseEntity]: ...

class OneWireProxyBinarySensor(OneWireProxyEntity, BinarySensorEntity):
    @property
    def is_on(self) -> bool: ...



from . import FritzBoxEntity as FritzBoxEntity
from .const import ATTR_STATE_BATTERY_LOW as ATTR_STATE_BATTERY_LOW, ATTR_STATE_DEVICE_LOCKED as ATTR_STATE_DEVICE_LOCKED, ATTR_STATE_HOLIDAY_MODE as ATTR_STATE_HOLIDAY_MODE, ATTR_STATE_LOCKED as ATTR_STATE_LOCKED, ATTR_STATE_SUMMER_MODE as ATTR_STATE_SUMMER_MODE, ATTR_STATE_WINDOW_OPEN as ATTR_STATE_WINDOW_OPEN, CONF_COORDINATOR as CONF_COORDINATOR
from .model import ClimateExtraAttributes as ClimateExtraAttributes
from homeassistant.components.climate import ClimateEntity as ClimateEntity
from homeassistant.components.climate.const import ATTR_HVAC_MODE as ATTR_HVAC_MODE, HVAC_MODE_HEAT as HVAC_MODE_HEAT, HVAC_MODE_OFF as HVAC_MODE_OFF, PRESET_COMFORT as PRESET_COMFORT, PRESET_ECO as PRESET_ECO, SUPPORT_PRESET_MODE as SUPPORT_PRESET_MODE, SUPPORT_TARGET_TEMPERATURE as SUPPORT_TARGET_TEMPERATURE
from homeassistant.components.sensor import ATTR_STATE_CLASS as ATTR_STATE_CLASS
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import ATTR_BATTERY_LEVEL as ATTR_BATTERY_LEVEL, ATTR_DEVICE_CLASS as ATTR_DEVICE_CLASS, ATTR_ENTITY_ID as ATTR_ENTITY_ID, ATTR_NAME as ATTR_NAME, ATTR_TEMPERATURE as ATTR_TEMPERATURE, ATTR_UNIT_OF_MEASUREMENT as ATTR_UNIT_OF_MEASUREMENT, PRECISION_HALVES as PRECISION_HALVES, TEMP_CELSIUS as TEMP_CELSIUS
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any

SUPPORT_FLAGS: Any
OPERATION_LIST: Any
MIN_TEMPERATURE: int
MAX_TEMPERATURE: int
PRESET_MANUAL: str
ON_API_TEMPERATURE: float
OFF_API_TEMPERATURE: float
ON_REPORT_SET_TEMPERATURE: float
OFF_REPORT_SET_TEMPERATURE: float

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class FritzboxThermostat(FritzBoxEntity, ClimateEntity):
    @property
    def supported_features(self) -> int: ...
    @property
    def temperature_unit(self) -> str: ...
    @property
    def precision(self) -> float: ...
    @property
    def current_temperature(self) -> float: ...
    @property
    def target_temperature(self) -> float: ...
    async def async_set_temperature(self, **kwargs: Any) -> None: ...
    @property
    def hvac_mode(self) -> str: ...
    @property
    def hvac_modes(self) -> list[str]: ...
    async def async_set_hvac_mode(self, hvac_mode: str) -> None: ...
    @property
    def preset_mode(self) -> Union[str, None]: ...
    @property
    def preset_modes(self) -> list[str]: ...
    async def async_set_preset_mode(self, preset_mode: str) -> None: ...
    @property
    def min_temp(self) -> int: ...
    @property
    def max_temp(self) -> int: ...
    @property
    def extra_state_attributes(self) -> ClimateExtraAttributes: ...



import abc
import voluptuous as vol
from . import disconnect_client as disconnect_client
from .addon import AddonError as AddonError, AddonInfo as AddonInfo, AddonManager as AddonManager, AddonState as AddonState, get_addon_manager as get_addon_manager
from .const import CONF_ADDON_DEVICE as CONF_ADDON_DEVICE, CONF_ADDON_EMULATE_HARDWARE as CONF_ADDON_EMULATE_HARDWARE, CONF_ADDON_LOG_LEVEL as CONF_ADDON_LOG_LEVEL, CONF_ADDON_NETWORK_KEY as CONF_ADDON_NETWORK_KEY, CONF_INTEGRATION_CREATED_ADDON as CONF_INTEGRATION_CREATED_ADDON, CONF_NETWORK_KEY as CONF_NETWORK_KEY, CONF_USB_PATH as CONF_USB_PATH, CONF_USE_ADDON as CONF_USE_ADDON, DOMAIN as DOMAIN
from abc import abstractmethod
from homeassistant import config_entries as config_entries, exceptions as exceptions
from homeassistant.components.hassio import is_hassio as is_hassio
from homeassistant.const import CONF_URL as CONF_URL
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.data_entry_flow import AbortFlow as AbortFlow, FlowHandler as FlowHandler, FlowManager as FlowManager, FlowResult as FlowResult
from homeassistant.helpers.aiohttp_client import async_get_clientsession as async_get_clientsession
from typing import Any
from zwave_js_server.version import VersionInfo as VersionInfo

_LOGGER: Any
DEFAULT_URL: str
TITLE: str
ADDON_SETUP_TIMEOUT: int
ADDON_SETUP_TIMEOUT_ROUNDS: int
CONF_EMULATE_HARDWARE: str
CONF_LOG_LEVEL: str
SERVER_VERSION_TIMEOUT: int
ADDON_LOG_LEVELS: Any
ADDON_USER_INPUT_MAP: Any
ON_SUPERVISOR_SCHEMA: Any

def get_manual_schema(user_input: dict[str, Any]) -> vol.Schema: ...
def get_on_supervisor_schema(user_input: dict[str, Any]) -> vol.Schema: ...
async def validate_input(hass: HomeAssistant, user_input: dict) -> VersionInfo: ...
async def async_get_version_info(hass: HomeAssistant, ws_address: str) -> VersionInfo: ...

class BaseZwaveJSFlow(FlowHandler, metaclass=abc.ABCMeta):
    network_key: Any
    usb_path: Any
    ws_address: Any
    restart_addon: bool
    integration_created_addon: bool
    install_task: Any
    start_task: Any
    version_info: Any
    def __init__(self) -> None: ...
    @property
    @abstractmethod
    def flow_manager(self) -> FlowManager: ...
    async def async_step_install_addon(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_install_failed(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_start_addon(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_start_failed(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def _async_start_addon(self) -> None: ...
    @abstractmethod
    async def async_step_configure_addon(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    @abstractmethod
    async def async_step_finish_addon_setup(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def _async_get_addon_info(self) -> AddonInfo: ...
    async def _async_set_addon_config(self, config: dict) -> None: ...
    async def _async_install_addon(self) -> None: ...
    async def _async_get_addon_discovery_info(self) -> dict: ...

class ConfigFlow(BaseZwaveJSFlow, config_entries.ConfigFlow):
    VERSION: int
    use_addon: bool
    def __init__(self) -> None: ...
    @property
    def flow_manager(self) -> config_entries.ConfigEntriesFlowManager: ...
    @staticmethod
    def async_get_options_flow(config_entry: config_entries.ConfigEntry) -> OptionsFlowHandler: ...
    async def async_step_user(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    ws_address: Any
    async def async_step_manual(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_hassio(self, discovery_info: dict[str, Any]) -> FlowResult: ...
    async def async_step_hassio_confirm(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    usb_path: Any
    network_key: Any
    async def async_step_on_supervisor(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_configure_addon(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    version_info: Any
    async def async_step_finish_addon_setup(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    def _async_create_entry_from_vars(self) -> FlowResult: ...

class OptionsFlowHandler(BaseZwaveJSFlow, config_entries.OptionsFlow):
    config_entry: Any
    original_addon_config: Any
    revert_reason: Any
    def __init__(self, config_entry: config_entries.ConfigEntry) -> None: ...
    @property
    def flow_manager(self) -> config_entries.OptionsFlowManager: ...
    def _async_update_entry(self, data: dict[str, Any]) -> None: ...
    async def async_step_init(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_manual(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_on_supervisor(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    network_key: Any
    usb_path: Any
    restart_addon: bool
    async def async_step_configure_addon(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_step_start_failed(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    ws_address: Any
    version_info: Any
    async def async_step_finish_addon_setup(self, user_input: Union[dict[str, Any], None] = ...) -> FlowResult: ...
    async def async_revert_addon_config(self, reason: str) -> FlowResult: ...

class CannotConnect(exceptions.HomeAssistantError): ...

class InvalidInput(exceptions.HomeAssistantError):
    error: Any
    def __init__(self, error: str) -> None: ...



from .const import DATA_SUBSCRIBER as DATA_SUBSCRIBER, DOMAIN as DOMAIN
from .device_info import NestDeviceInfo as NestDeviceInfo
from google_nest_sdm.device import Device as Device
from google_nest_sdm.thermostat_traits import ThermostatHeatCoolTrait as ThermostatHeatCoolTrait
from homeassistant.components.climate import ClimateEntity as ClimateEntity
from homeassistant.components.climate.const import ATTR_TARGET_TEMP_HIGH as ATTR_TARGET_TEMP_HIGH, ATTR_TARGET_TEMP_LOW as ATTR_TARGET_TEMP_LOW, CURRENT_HVAC_COOL as CURRENT_HVAC_COOL, CURRENT_HVAC_HEAT as CURRENT_HVAC_HEAT, CURRENT_HVAC_OFF as CURRENT_HVAC_OFF, FAN_OFF as FAN_OFF, FAN_ON as FAN_ON, HVAC_MODE_AUTO as HVAC_MODE_AUTO, HVAC_MODE_COOL as HVAC_MODE_COOL, HVAC_MODE_FAN_ONLY as HVAC_MODE_FAN_ONLY, HVAC_MODE_HEAT as HVAC_MODE_HEAT, HVAC_MODE_HEAT_COOL as HVAC_MODE_HEAT_COOL, HVAC_MODE_OFF as HVAC_MODE_OFF, PRESET_ECO as PRESET_ECO, PRESET_NONE as PRESET_NONE, SUPPORT_FAN_MODE as SUPPORT_FAN_MODE, SUPPORT_PRESET_MODE as SUPPORT_PRESET_MODE, SUPPORT_TARGET_TEMPERATURE as SUPPORT_TARGET_TEMPERATURE, SUPPORT_TARGET_TEMPERATURE_RANGE as SUPPORT_TARGET_TEMPERATURE_RANGE
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import ATTR_TEMPERATURE as ATTR_TEMPERATURE, TEMP_CELSIUS as TEMP_CELSIUS
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.exceptions import PlatformNotReady as PlatformNotReady
from homeassistant.helpers.entity import DeviceInfo as DeviceInfo
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any

THERMOSTAT_MODE_MAP: dict[str, str]
THERMOSTAT_INV_MODE_MAP: Any
THERMOSTAT_ECO_MODE: str
THERMOSTAT_HVAC_STATUS_MAP: Any
THERMOSTAT_RANGE_MODES: Any
PRESET_MODE_MAP: Any
PRESET_INV_MODE_MAP: Any
FAN_MODE_MAP: Any
FAN_INV_MODE_MAP: Any
MAX_FAN_DURATION: int

async def async_setup_sdm_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class ThermostatEntity(ClimateEntity):
    _device: Any
    _device_info: Any
    _supported_features: int
    def __init__(self, device: Device) -> None: ...
    @property
    def should_poll(self) -> bool: ...
    @property
    def unique_id(self) -> Union[str, None]: ...
    @property
    def name(self) -> Union[str, None]: ...
    @property
    def device_info(self) -> DeviceInfo: ...
    async def async_added_to_hass(self) -> None: ...
    @property
    def temperature_unit(self) -> str: ...
    @property
    def current_temperature(self) -> Union[float, None]: ...
    @property
    def target_temperature(self) -> Union[float, None]: ...
    @property
    def target_temperature_high(self) -> Union[float, None]: ...
    @property
    def target_temperature_low(self) -> Union[float, None]: ...
    @property
    def _target_temperature_trait(self) -> Union[ThermostatHeatCoolTrait, None]: ...
    @property
    def hvac_mode(self) -> str: ...
    @property
    def hvac_modes(self) -> list[str]: ...
    @property
    def _get_device_hvac_modes(self) -> set[str]: ...
    @property
    def hvac_action(self) -> Union[str, None]: ...
    @property
    def preset_mode(self) -> str: ...
    @property
    def preset_modes(self) -> list[str]: ...
    @property
    def fan_mode(self) -> str: ...
    @property
    def fan_modes(self) -> list[str]: ...
    @property
    def supported_features(self) -> int: ...
    def _get_supported_features(self) -> int: ...
    async def async_set_hvac_mode(self, hvac_mode: str) -> None: ...
    async def async_set_temperature(self, **kwargs: Any) -> None: ...
    async def async_set_preset_mode(self, preset_mode: str) -> None: ...
    async def async_set_fan_mode(self, fan_mode: str) -> None: ...



from . import DOMAIN as DOMAIN
from .climate import STATE_NETATMO_AWAY as STATE_NETATMO_AWAY, STATE_NETATMO_HG as STATE_NETATMO_HG, STATE_NETATMO_SCHEDULE as STATE_NETATMO_SCHEDULE
from .const import CLIMATE_TRIGGERS as CLIMATE_TRIGGERS, EVENT_TYPE_THERM_MODE as EVENT_TYPE_THERM_MODE, INDOOR_CAMERA_TRIGGERS as INDOOR_CAMERA_TRIGGERS, MODEL_NACAMERA as MODEL_NACAMERA, MODEL_NATHERM1 as MODEL_NATHERM1, MODEL_NOC as MODEL_NOC, MODEL_NRV as MODEL_NRV, NETATMO_EVENT as NETATMO_EVENT, OUTDOOR_CAMERA_TRIGGERS as OUTDOOR_CAMERA_TRIGGERS
from homeassistant.components.automation import AutomationActionType as AutomationActionType
from homeassistant.components.device_automation import DEVICE_TRIGGER_BASE_SCHEMA as DEVICE_TRIGGER_BASE_SCHEMA
from homeassistant.components.device_automation.exceptions import InvalidDeviceAutomationConfig as InvalidDeviceAutomationConfig
from homeassistant.const import ATTR_DEVICE_ID as ATTR_DEVICE_ID, CONF_DEVICE_ID as CONF_DEVICE_ID, CONF_DOMAIN as CONF_DOMAIN, CONF_ENTITY_ID as CONF_ENTITY_ID, CONF_PLATFORM as CONF_PLATFORM, CONF_TYPE as CONF_TYPE
from homeassistant.core import CALLBACK_TYPE as CALLBACK_TYPE, HomeAssistant as HomeAssistant
from homeassistant.helpers import entity_registry as entity_registry
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any

CONF_SUBTYPE: str
DEVICES: Any
SUBTYPES: Any
TRIGGER_TYPES: Any
TRIGGER_SCHEMA: Any

async def async_validate_trigger_config(hass: HomeAssistant, config: ConfigType) -> ConfigType: ...
async def async_get_triggers(hass: HomeAssistant, device_id: str) -> list[dict]: ...
async def async_attach_trigger(hass: HomeAssistant, config: ConfigType, action: AutomationActionType, automation_info: dict) -> CALLBACK_TYPE: ...



from . import PiHoleEntity as PiHoleEntity
from .const import ATTR_BLOCKED_DOMAINS as ATTR_BLOCKED_DOMAINS, DATA_KEY_API as DATA_KEY_API, DATA_KEY_COORDINATOR as DATA_KEY_COORDINATOR, SENSOR_DICT as SENSOR_DICT, SENSOR_LIST as SENSOR_LIST
from hole import Hole as Hole
from homeassistant.components.sensor import SensorEntity as SensorEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import CONF_NAME as CONF_NAME
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.update_coordinator import DataUpdateCoordinator as DataUpdateCoordinator
from typing import Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class PiHoleSensor(PiHoleEntity, SensorEntity):
    _condition: Any
    _condition_name: Any
    _unit_of_measurement: Any
    _icon: Any
    def __init__(self, api: Hole, coordinator: DataUpdateCoordinator, name: str, sensor_name: str, server_unique_id: str) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def unique_id(self) -> str: ...
    @property
    def icon(self) -> str: ...
    @property
    def unit_of_measurement(self) -> str: ...
    @property
    def state(self) -> Any: ...
    @property
    def extra_state_attributes(self) -> dict[str, Any]: ...



from .const import DATA_CLIENT as DATA_CLIENT, DOMAIN as DOMAIN
from .discovery import ZwaveDiscoveryInfo as ZwaveDiscoveryInfo
from .entity import ZWaveBaseEntity as ZWaveBaseEntity
from homeassistant.components.siren import SirenEntity as SirenEntity
from homeassistant.components.siren.const import ATTR_TONE as ATTR_TONE, ATTR_VOLUME_LEVEL as ATTR_VOLUME_LEVEL, SUPPORT_TONES as SUPPORT_TONES, SUPPORT_TURN_OFF as SUPPORT_TURN_OFF, SUPPORT_TURN_ON as SUPPORT_TURN_ON, SUPPORT_VOLUME_SET as SUPPORT_VOLUME_SET
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.dispatcher import async_dispatcher_connect as async_dispatcher_connect
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from typing import Any
from zwave_js_server.client import Client as ZwaveClient

async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class ZwaveSirenEntity(ZWaveBaseEntity, SirenEntity):
    _attr_available_tones: Any
    _attr_supported_features: Any
    def __init__(self, config_entry: ConfigEntry, client: ZwaveClient, info: ZwaveDiscoveryInfo) -> None: ...
    @property
    def is_on(self) -> bool: ...
    async def async_set_value(self, new_value: int, options: Union[dict[str, Any], None] = ...) -> None: ...
    async def async_turn_on(self, **kwargs: Any) -> None: ...
    async def async_turn_off(self, **kwargs: Any) -> None: ...



from . import LcnEntity as LcnEntity
from .const import CONF_DOMAIN_DATA as CONF_DOMAIN_DATA, CONF_OUTPUTS as CONF_OUTPUTS, CONF_REGISTER as CONF_REGISTER, CONF_TRANSITION as CONF_TRANSITION, OUTPUT_PORTS as OUTPUT_PORTS
from .helpers import DeviceConnectionType as DeviceConnectionType, get_device_connection as get_device_connection
from homeassistant.components.scene import Scene as Scene
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import CONF_ADDRESS as CONF_ADDRESS, CONF_DOMAIN as CONF_DOMAIN, CONF_ENTITIES as CONF_ENTITIES, CONF_SCENE as CONF_SCENE
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity_platform import AddEntitiesCallback as AddEntitiesCallback
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any

PARALLEL_UPDATES: int

def create_lcn_scene_entity(hass: HomeAssistant, entity_config: ConfigType, config_entry: ConfigEntry) -> LcnEntity: ...
async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: AddEntitiesCallback) -> None: ...

class LcnScene(LcnEntity, Scene):
    register_id: Any
    scene_id: Any
    output_ports: Any
    relay_ports: Any
    transition: Any
    def __init__(self, config: ConfigType, entry_id: str, device_connection: DeviceConnectionType) -> None: ...
    async def async_activate(self, **kwargs: Any) -> None: ...



from typing import Any

DOMAIN: str
ATTR_UNIQUE_ID: str
CONF_TRACK_WIRED_CLIENTS: str
CONF_UNAUTHENTICATED_MODE: str
DEFAULT_DEVICE_NAME: str
DEFAULT_NOTIFY_SERVICE_NAME = DOMAIN
DEFAULT_TRACK_WIRED_CLIENTS: bool
DEFAULT_UNAUTHENTICATED_MODE: bool
UPDATE_SIGNAL: Any
CONNECTION_TIMEOUT: int
NOTIFY_SUPPRESS_TIMEOUT: int
SERVICE_CLEAR_TRAFFIC_STATISTICS: str
SERVICE_REBOOT: str
SERVICE_RESUME_INTEGRATION: str
SERVICE_SUSPEND_INTEGRATION: str
ADMIN_SERVICES: Any
KEY_DEVICE_BASIC_INFORMATION: str
KEY_DEVICE_INFORMATION: str
KEY_DEVICE_SIGNAL: str
KEY_DIALUP_MOBILE_DATASWITCH: str
KEY_LAN_HOST_INFO: str
KEY_MONITORING_CHECK_NOTIFICATIONS: str
KEY_MONITORING_MONTH_STATISTICS: str
KEY_MONITORING_STATUS: str
KEY_MONITORING_TRAFFIC_STATISTICS: str
KEY_NET_CURRENT_PLMN: str
KEY_NET_NET_MODE: str
KEY_SMS_SMS_COUNT: str
KEY_WLAN_HOST_LIST: str
KEY_WLAN_WIFI_FEATURE_SWITCH: str
BINARY_SENSOR_KEYS: Any
DEVICE_TRACKER_KEYS: Any
SENSOR_KEYS: Any
SWITCH_KEYS: Any
ALL_KEYS: Any



from .const import CONF_DEVICE_TOKEN as CONF_DEVICE_TOKEN, CONF_SERIAL as CONF_SERIAL, COORDINATOR_CAMERAS as COORDINATOR_CAMERAS, COORDINATOR_CENTRAL as COORDINATOR_CENTRAL, COORDINATOR_SWITCHES as COORDINATOR_SWITCHES, DEFAULT_SCAN_INTERVAL as DEFAULT_SCAN_INTERVAL, DEFAULT_VERIFY_SSL as DEFAULT_VERIFY_SSL, DOMAIN as DOMAIN, ENTITY_ENABLE as ENTITY_ENABLE, EXCEPTION_DETAILS as EXCEPTION_DETAILS, EXCEPTION_UNKNOWN as EXCEPTION_UNKNOWN, EntityInfo as EntityInfo, PLATFORMS as PLATFORMS, SERVICES as SERVICES, SERVICE_REBOOT as SERVICE_REBOOT, SERVICE_SHUTDOWN as SERVICE_SHUTDOWN, STORAGE_DISK_BINARY_SENSORS as STORAGE_DISK_BINARY_SENSORS, STORAGE_DISK_SENSORS as STORAGE_DISK_SENSORS, STORAGE_VOL_SENSORS as STORAGE_VOL_SENSORS, SYNO_API as SYNO_API, SYSTEM_LOADED as SYSTEM_LOADED, UNDO_UPDATE_LISTENER as UNDO_UPDATE_LISTENER, UTILISATION_SENSORS as UTILISATION_SENSORS
from datetime import timedelta
from homeassistant.components.sensor import ATTR_STATE_CLASS as ATTR_STATE_CLASS
from homeassistant.config_entries import ConfigEntry as ConfigEntry, SOURCE_REAUTH as SOURCE_REAUTH
from homeassistant.const import ATTR_ATTRIBUTION as ATTR_ATTRIBUTION, ATTR_DEVICE_CLASS as ATTR_DEVICE_CLASS, ATTR_ICON as ATTR_ICON, ATTR_NAME as ATTR_NAME, ATTR_UNIT_OF_MEASUREMENT as ATTR_UNIT_OF_MEASUREMENT, CONF_HOST as CONF_HOST, CONF_MAC as CONF_MAC, CONF_PASSWORD as CONF_PASSWORD, CONF_PORT as CONF_PORT, CONF_SCAN_INTERVAL as CONF_SCAN_INTERVAL, CONF_SSL as CONF_SSL, CONF_TIMEOUT as CONF_TIMEOUT, CONF_USERNAME as CONF_USERNAME, CONF_VERIFY_SSL as CONF_VERIFY_SSL
from homeassistant.core import HomeAssistant as HomeAssistant, ServiceCall as ServiceCall, callback as callback
from homeassistant.exceptions import ConfigEntryNotReady as ConfigEntryNotReady
from homeassistant.helpers import device_registry as device_registry, entity_registry as entity_registry
from homeassistant.helpers.device_registry import DeviceEntry as DeviceEntry
from homeassistant.helpers.entity import DeviceInfo as DeviceInfo
from homeassistant.helpers.update_coordinator import CoordinatorEntity as CoordinatorEntity, DataUpdateCoordinator as DataUpdateCoordinator, UpdateFailed as UpdateFailed
from synology_dsm.api.dsm.network import SynoDSMNetwork as SynoDSMNetwork
from synology_dsm.api.surveillance_station.camera import SynoCamera as SynoCamera
from typing import Any, Callable

CONFIG_SCHEMA: Any
ATTRIBUTION: str
_LOGGER: Any

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool: ...
async def _async_update_listener(hass: HomeAssistant, entry: ConfigEntry) -> None: ...
async def _async_setup_services(hass: HomeAssistant) -> None: ...

class SynoApi:
    _hass: Any
    _entry: Any
    dsm: Any
    information: Any
    network: Any
    security: Any
    storage: Any
    surveillance_station: Any
    system: Any
    upgrade: Any
    utilisation: Any
    _fetching_entities: Any
    _with_information: bool
    _with_security: bool
    _with_storage: bool
    _with_surveillance_station: bool
    _with_system: bool
    _with_upgrade: bool
    _with_utilisation: bool
    def __init__(self, hass: HomeAssistant, entry: ConfigEntry) -> None: ...
    async def async_setup(self) -> None: ...
    def subscribe(self, api_key: str, unique_id: str) -> Callable[[], None]: ...
    def _async_setup_api_requests(self) -> None: ...
    def _fetch_device_configuration(self) -> None: ...
    async def async_reboot(self) -> None: ...
    async def async_shutdown(self) -> None: ...
    async def async_unload(self) -> None: ...
    async def async_update(self, now: Union[timedelta, None] = ...) -> None: ...

class SynologyDSMBaseEntity(CoordinatorEntity):
    _api: Any
    _api_key: Any
    entity_type: Any
    _name: Any
    _class: Any
    _enable_default: Any
    _icon: Any
    _unit: Any
    _unique_id: Any
    _attr_state_class: Any
    def __init__(self, api: SynoApi, entity_type: str, entity_info: EntityInfo, coordinator: DataUpdateCoordinator[dict[str, dict[str, Any]]]) -> None: ...
    @property
    def unique_id(self) -> str: ...
    @property
    def name(self) -> str: ...
    @property
    def icon(self) -> Union[str, None]: ...
    @property
    def device_class(self) -> Union[str, None]: ...
    @property
    def extra_state_attributes(self) -> dict[str, Any]: ...
    @property
    def device_info(self) -> DeviceInfo: ...
    @property
    def entity_registry_enabled_default(self) -> bool: ...
    async def async_added_to_hass(self) -> None: ...

class SynologyDSMDeviceEntity(SynologyDSMBaseEntity):
    _device_id: Any
    _device_name: Any
    _device_manufacturer: Any
    _device_model: Any
    _device_firmware: Any
    _device_type: Any
    _name: Any
    def __init__(self, api: SynoApi, entity_type: str, entity_info: EntityInfo, coordinator: DataUpdateCoordinator[dict[str, dict[str, Any]]], device_id: Union[str, None] = ...) -> None: ...
    @property
    def available(self) -> bool: ...
    @property
    def device_info(self) -> DeviceInfo: ...
